@@ -153,9 +153,10 @@ def _download_and_unpack_bundle(bundle_type):
 
     try:
         LOGGER.info('Unpacking {} to {}'.format(bundle.name, extraction_path))
+        print([m for m in archive.getmembers() if m.name != ''])
         archive.extractall(
-            extraction_path,
-            [m for m in archive.getmembers() if m.name != ''])
+            path=extraction_path,
+            members=[m for m in archive.getmembers() if m.name != ''])
     except Exception as err:
         LOGGER.error('Error when unpacking bundle: {}'.format(err))
     finally:
